import { CoreMessage, CoreTool as CT, LanguageModelV1 } from 'ai';
import { JSONSchema7 } from 'json-schema';
import { z, ZodSchema } from 'zod';
import 'dotenv/config';
import { ToolsInput } from '../agent/types';
import { MastraBase } from '../base';
import { Run } from '../run/types';
import { CoreTool } from '../tools/types';
import { CustomModelConfig, GenerateReturn, GoogleGenerativeAISettings, ModelConfig, OutputType, StreamReturn, StructuredOutput } from './types';
export declare class LLM extends MastraBase {
    #private;
    constructor({ model }: {
        model: ModelConfig;
    });
    getModelType(): string;
    createOpenAICompatibleModel({ baseURL, apiKey, defaultModelName, modelName, fetch, }: {
        baseURL: string;
        apiKey: string;
        defaultModelName: string;
        modelName?: string;
        fetch?: typeof globalThis.fetch;
    }): LanguageModelV1;
    createModelDef({ model, }: {
        model: {
            type: string;
            name?: string;
            toolChoice?: 'auto' | 'required';
            baseURL?: string;
            fetch?: typeof globalThis.fetch;
            apiKey?: string;
        };
    }): LanguageModelV1;
    getParams({ tools, resultTool, model, }: {
        tools: Record<string, CoreTool>;
        resultTool?: {
            description: string;
            parameters: ZodSchema;
        };
        model: ({
            type: string;
            name?: string;
            toolChoice?: 'auto' | 'required';
            baseURL?: string;
            apiKey?: string;
            fetch?: typeof globalThis.fetch;
        } & GoogleGenerativeAISettings) | CustomModelConfig;
    }): Promise<{
        toolsConverted: Record<string, CT>;
        modelDef: LanguageModelV1;
        answerTool: {};
        toolChoice: "auto" | "required";
    }>;
    convertTools(tools?: ToolsInput): Record<string, CoreTool>;
    private convertToMessages;
    generate<Z extends ZodSchema | JSONSchema7 | undefined = undefined>(messages: string | string[] | CoreMessage[], { maxSteps, onStepFinish, tools, convertedTools, runId, output, }?: {
        runId?: string;
        onFinish?: (result: string) => Promise<void> | void;
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
        tools?: ToolsInput;
        convertedTools?: Record<string, CoreTool>;
        output?: OutputType | Z;
    }): Promise<GenerateReturn<Z>>;
    stream<Z extends ZodSchema | JSONSchema7 | undefined = undefined>(messages: string | string[] | CoreMessage[], { maxSteps, onFinish, onStepFinish, tools, convertedTools, runId, output, }?: {
        runId?: string;
        onFinish?: (result: string) => Promise<void> | void;
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
        tools?: ToolsInput;
        convertedTools?: Record<string, CoreTool>;
        output?: OutputType | Z;
    }): Promise<StreamReturn<Z>>;
    __text({ messages, onStepFinish, maxSteps, tools, runId, convertedTools, }: {
        tools?: ToolsInput;
        convertedTools?: Record<string, CoreTool>;
        messages: CoreMessage[];
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
    } & Run): Promise<import("ai").GenerateTextResult<{}, never>>;
    __textObject<T>({ messages, onStepFinish, maxSteps, tools, convertedTools, structuredOutput, runId, }: {
        structuredOutput: JSONSchema7 | z.ZodType<T> | StructuredOutput;
        tools?: ToolsInput;
        convertedTools?: Record<string, CoreTool>;
        messages: CoreMessage[];
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
    } & Run): Promise<import("ai").GenerateObjectResult<T>>;
    __stream({ messages, onStepFinish, onFinish, maxSteps, tools, runId, convertedTools, }: {
        tools?: ToolsInput;
        convertedTools?: Record<string, CoreTool>;
        messages: CoreMessage[];
        onStepFinish?: (step: string) => void;
        onFinish?: (result: string) => Promise<void> | void;
        maxSteps?: number;
    } & Run): Promise<import("ai").StreamTextResult<{}, never>>;
    __streamObject<T>({ messages, onStepFinish, onFinish, maxSteps, tools, convertedTools, structuredOutput, runId, }: {
        structuredOutput: JSONSchema7 | z.ZodType<T> | StructuredOutput;
        tools?: ToolsInput;
        convertedTools?: Record<string, CoreTool>;
        messages: CoreMessage[];
        onStepFinish?: (step: string) => void;
        onFinish?: (result: string) => Promise<void> | void;
        maxSteps?: number;
    } & Run): Promise<import("ai").StreamObjectResult<import("ai").DeepPartial<T>, T, never>>;
}
//# sourceMappingURL=index.d.ts.map